.. _sage.combinat:

Combinatorics
=============

.. automodule:: sage.combinat.all
   :noindex:

Comprehensive Module List
-------------------------

.. toctree::
   :maxdepth: 1

   module_list

.. include:: ../footer.txt

